//************************************************************************************************************************** 
//* Blue HttpMail Extension
//* Copyright (c) 2003-2004 Josh Harler
//* 
//* Blue - General Purpose C++ Library
//* Copyright (c) 2002-2004 Josh Harler
//* 
//* This software is provided 'as-is', without any express or implied warranty. In no event
//* will the authors be held liable for any damages arising from the use of this software.
//* 
//* Permission is granted to anyone to use this software for any purpose, including commercial
//* applications, and to alter it and redistribute it freely, subject to the following restrictions:
//* 
//* 	1. The origin of this software must not be misrepresented; you must not claim that you
//* 	wrote the original software. If you use this software in a product, an acknowledgment in the
//* 	product documentation would be appreciated but is not required.
//* 
//* 	2. Altered source versions must be plainly marked as such, and must not be misrepresented as
//* 	being the original software.
//* 
//* 	3. This notice may not be removed or altered from any source distribution.
//*
//*
//* file   Blue/Extension/HttpMail/Message.cpp
//**

// Private Headers =========================================================================================================

// matching header
#include "Message.h"

// Extension headers
#include "Blue/Extension/HttpMail/Mailbox.h"


// Private Defines/Enums/Typedefs/Etc ======================================================================================

using namespace blue;
using namespace blue::common;
using namespace blue::ext;
using namespace blue::ext::http;


// Private Classes/Structs =================================================================================================

// Private Global Variables ================================================================================================

// External Global Variables ===============================================================================================

// Private Functions =======================================================================================================

// Functions ===============================================================================================================

namespace blue {
namespace ext {
namespace httpmail {

	// ---------------------------------------------------------------------------------------------------------------------

	Message::Message( Mailbox& mailbox, String url )
		:m_mailbox(mailbox), m_url(url), m_isRead(false), m_contentLength(0)
	{
	}

	// ---------------------------------------------------------------------------------------------------------------------

	Message::~Message()
	{
	}

	// ---------------------------------------------------------------------------------------------------------------------

	String Message::getUrl() const
	{
		return (m_url);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	String Message::getID() const
	{
		int posSlash = m_url.findPosR("/");
		if( posSlash == String::npos ) {
			return (String::null);
		}

		return m_url.subString(posSlash+1);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	bool Message::isLoaded() const
	{
		return (m_content != Buffer::null);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	bool Message::isRead() const
	{
		return (m_isRead);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	int Message::getContentLength() const
	{
		return (m_contentLength);
	}

	// ---------------------------------------------------------------------------------------------------------------------
	
	String Message::getFrom() const
	{
		return (m_from);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	String Message::getSubject() const
	{
		return (m_subject);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	util::DateTime Message::getDate() const
	{
		return (m_date);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	const Buffer Message::getContent() const
	{
		return (m_content);
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::setUrl( String url )
	{
		m_url = url;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::setRead( bool read )
	{
		m_isRead = read;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::setContentLength( int length )
	{
		m_contentLength = length;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::setFrom( String from )
	{
		m_from = from;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::setSubject( String subject )
	{
		m_subject = subject;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::setDate( util::DateTime date )
	{
		m_date = date;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::load()
	{
		Url url(m_url);

		String errMsg;
		String result = m_mailbox.processWebDavRequest(url, "GET", String::null, errMsg);

		if( result == String::null ) {
			throw MessageLoadException("Unable to get mail message: " + errMsg);
		}

		m_content = result;
	}

	// ---------------------------------------------------------------------------------------------------------------------

	void Message::unload()
	{
		m_content = Buffer::null;
	}

}}}	// namespaces
